==> apache-uniffle-0.7.1-incubating-src.tar.gz: apache-uniffle-0.7.1-incubating-src/common/src/test/java/org/apache/uniffle/common/metrics/MetricReporterFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common.metrics;

import org.junit.jupiter.api.Test;

import org.apache.uniffle.common.config.RssBaseConf;
import org.apache.uniffle.common.config.RssConf;
import org.apache.uniffle.common.metrics.prometheus.PrometheusPushGatewayMetricReporter;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class MetricReporterFactoryTest {

  @Test
  public void testGetMetricReporter() throws Exception {
    CustomRssConf conf = new CustomRssConf();
    conf.set(RssBaseConf.RSS_METRICS_REPORTER_CLASS,
        PrometheusPushGatewayMetricReporter.class.getCanonicalName());
    MetricReporter metricReporter = MetricReporterFactory.getMetricReporter(conf, "1");
    assertTrue(metricReporter instanceof PrometheusPushGatewayMetricReporter);
  }

  class CustomRssConf extends RssConf {

  }
}

==> apache-uniffle-0.9.0-incubating-src.tar.gz: apache-uniffle-0.9.0-incubating-src/common/src/test/java/org/apache/uniffle/common/metrics/MetricReporterFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common.metrics;

import org.junit.jupiter.api.Test;

import org.apache.uniffle.common.config.RssBaseConf;
import org.apache.uniffle.common.config.RssConf;
import org.apache.uniffle.common.metrics.prometheus.PrometheusPushGatewayMetricReporter;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class MetricReporterFactoryTest {

  @Test
  public void testGetMetricReporter() throws Exception {
    CustomRssConf conf = new CustomRssConf();
    conf.set(
        RssBaseConf.RSS_METRICS_REPORTER_CLASS,
        PrometheusPushGatewayMetricReporter.class.getCanonicalName());
    MetricReporter metricReporter = MetricReporterFactory.getMetricReporter(conf, "1");
    assertTrue(metricReporter instanceof PrometheusPushGatewayMetricReporter);
  }

  class CustomRssConf extends RssConf {}
}
